#Topsis-Akshit-101903151
Multiple criteria decision making (MCDM) using TOPSIS

## Installation
```pip install topsis-Akshit-101903151```

##Sample Use case
import topsis-Akshit-10903151 as t
t.topsis("input.csv","1,2,1,2,3","+,+,-,+,-","output.csv")
